'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ROUTE_IMPORT_VALUE = undefined;
exports.createFileMessage = createFileMessage;
exports.logRouteFewArguments = logRouteFewArguments;
exports.logRouteManyArguments = logRouteManyArguments;
exports.logRouteParentFewArguments = logRouteParentFewArguments;
exports.logRouteParentManyArguments = logRouteParentManyArguments;
exports.logRouteStringArguments = logRouteStringArguments;
exports.isRouteParentCallee = isRouteParentCallee;

var _logger = require('./logger');

var _logger2 = _interopRequireDefault(_logger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ROUTE_IMPORT_VALUE = exports.ROUTE_IMPORT_VALUE = 'vtex.renderjs/route.js';

function createFileMessage(message, node, state) {
  var filename = state.file.opts.filename;
  var loc = node.loc;

  return message + ' on ' + filename + ' (' + loc.start.line + ':' + loc.start.column + ')';
}

function logRouteFewArguments(routeFnIdentifier, node, state) {
  _logger2.default.error(createFileMessage('Too few arguments on ' + routeFnIdentifier + ' function', node, state));
}

function logRouteManyArguments(routeFnIdentifier, node, state) {
  _logger2.default.warn(createFileMessage('Too many arguments on ' + routeFnIdentifier + ' function', node, state));
}

function logRouteParentFewArguments(routeFnIdentifier, node, state) {
  _logger2.default.error(createFileMessage('Too few arguments on ' + routeFnIdentifier + ' returned function', node, state));
}

function logRouteParentManyArguments(routeFnIdentifier, node, state) {
  _logger2.default.warn(createFileMessage('Too many arguments on ' + routeFnIdentifier + ' returned function', node, state));
}

function logRouteStringArguments(routeFnIdentifier, node, state) {
  _logger2.default.error(createFileMessage('Arguments to the ' + routeFnIdentifier + ' function must be string literals', node, state));
}

function isRouteParentCallee(routeFnIdentifier, path) {
  var parentCallee = path.parent.callee;
  var isCallExpression = parentCallee.type === 'CallExpression';
  return isCallExpression ? parentCallee.callee.name === routeFnIdentifier : false;
}